@@ -8,7 +8,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ('all' => [ qw(new get_info make_report)]);
 our @EXPORT_OK = (@{$EXPORT_TAGS{'all'}});
 our @EXPORT = qw();
-our $VERSION ='1.3';
+our $VERSION ='1.4';
 #####################################################
 my ($class, $this, $router);
 #####################################################
@@ -47,8 +47,8 @@ sub get_info(){
                 $address = "$split2[2]-->$split2[3]" if $split2[3];
                 $address =~ s/\s//g;
                 $address = "No IPv4 address-->No mask" if !$split2[3];
-                $this->{"Interface-->".$interface."-->"} = "$address-->No description\n" if !$description;
-                $this->{"Interface-->".$interface."-->"} = "$address-->$description\n" if $description;
+                $this->{"Interface_".$interface."-->"} = "$address-->No description\n" if !$description;
+                $this->{"Interface_".$interface."-->"} = "$address-->$description\n" if $description;
             }
         }
     }
@@ -64,60 +64,11 @@ sub make_report(){
     print CSV "Name;Interface;IPv4 Address;Mask;Description\n";
     foreach my$int (sort keys %{$this}){
         my $intclean = $int;
-        $intclean =~ s/^Interface//;
+        $intclean =~ s/^Interface_//;
+        $intclean =~ s/-->/;/g;
+        $intclean.$this->{$int} =~ s/-->/;/g;
         print CSV $this->{name}.";".$intclean.$this->{$int} if $int =~ /^Interface/;
     }
     close CSV;
 }
 1;
-__END__
-
-
-=head1 NAME
-
-ios get interfaces - Get interfaces from cisco ios conf.
-
-=head1 SYNOPSIS
-
-use strict;
-
-use warnings;
-
-use ios_get_interfaces;
-
-my%info = (name => "router_a", showrun_file => "show_running_config.txt", csv=>"router_a.csv");
-
-my$router = ios_get_interfaces->new(\%info);
-
-my$interfaces = $router->get_info();
-
-print @{$interfaces};
-
-$router->make_report();
-
-=head1 DESCRIPTION
-
-
-Get interfaces from cisco ios conf
-
-
-=head2 EXPORT
-
-None by default.
-
-=head1 SEE ALSO
-
-=head1 AUTHOR
-
-Cladi, E<lt>cladi@cpan.orgE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2017 by Cladi Di Domenico
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.1 or,
-at your option, any later version of Perl 5 you may have available.
-
-
-=cut
